/*--------------------------------------------------------------------------+
$Id: ElementTreeMultiSelectDialogGUI.java 5186 2012-07-27 20:23:37Z ratiu $
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.wb.swt.ResourceManager;

/**
 * GUI for {@link ElementTreeMultiSelectDialog}
 * 
 * @author kisslinger
 * @author $Author: ratiu $
 * @version $Rev: 5186 $
 * @ConQAT.Rating YELLOW Hash: 769064121AB5F0337907ED252066A3FE
 */
public class ElementTreeMultiSelectEditableDialogGUI extends Composite {

	/** the left tree viewer */
	private TreeViewer elementTreeViewer;

	/** the right tree viewer */
	private TreeViewer selectTreeViewer;

	/** the select button */
	private Button selectButton;

	/** the deselect button */
	private Button deselectButton;

	/** GUI Factory */
	private final FormToolkit formToolkit = new FormToolkit(Display.getDefault());

	/** the create button */
	private Button createButton;

	/** the delete button */
	private Button deleteButton;

	/** the edit button */
	private Button editButton;

	/** */
	private Composite lefttoolbar;

	/** Default Constructor for GUI builder. */
	public ElementTreeMultiSelectEditableDialogGUI(Composite parent, int style) {
		super(parent, style);

		GridLayout gl_container = new GridLayout(4, false);
		gl_container.verticalSpacing = 2;
		gl_container.marginRight = 5;
		gl_container.marginLeft = 5;
		gl_container.marginBottom = 5;
		gl_container.marginTop = 5;
		gl_container.marginWidth = 0;
		gl_container.marginHeight = 0;
		setLayout(gl_container);
		setLayoutData(new GridData(GridData.FILL_BOTH));

		lefttoolbar = new Composite(this, SWT.NONE);
		lefttoolbar.setLayoutData(new GridData(SWT.CENTER, SWT.FILL, false, true, 1, 1));
		GridLayout gl_lefttoolbar = new GridLayout(1, false);
		gl_lefttoolbar.verticalSpacing = 2;
		gl_lefttoolbar.horizontalSpacing = 2;
		gl_lefttoolbar.marginHeight = 0;
		gl_lefttoolbar.marginWidth = 0;
		lefttoolbar.setLayout(gl_lefttoolbar);

		createButton = new Button(lefttoolbar, SWT.NONE);
		createButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/obj16/add_obj.gif"));
		formToolkit.adapt(createButton, true, true);

		deleteButton = new Button(lefttoolbar, SWT.NONE);
		deleteButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/obj16/delete_obj.gif"));
		formToolkit.adapt(deleteButton, true, true);

		editButton = new Button(lefttoolbar, SWT.NONE);
		editButton.setImage(ResourceManager.getPluginImage("org.eclipse.ui",
				"/icons/full/etool16/editor_area.gif"));
		formToolkit.adapt(editButton, true, true);

		elementTreeViewer = new TreeViewer(this, SWT.BORDER);
		Tree elementTree = elementTreeViewer.getTree();
		elementTree.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));

		Composite toolbarbox = new Composite(this, SWT.NONE);
		GridLayout gl_toolbarbox = new GridLayout(1, false);

		gl_toolbarbox.verticalSpacing = 2;
		gl_toolbarbox.horizontalSpacing = 2;
		gl_toolbarbox.marginHeight = 0;
		gl_toolbarbox.marginWidth = 0;
		toolbarbox.setLayout(gl_toolbarbox);
		toolbarbox.setLayoutData(new GridData(SWT.CENTER, SWT.CENTER, false, true, 1, 1));

		selectButton = new Button(toolbarbox, SWT.NONE);
		selectButton.setText(">>");

		deselectButton = new Button(toolbarbox, SWT.NONE);
		deselectButton.setText("<<");

		selectTreeViewer = new TreeViewer(this, SWT.BORDER);
		Tree selectTree = selectTreeViewer.getTree();
		selectTree.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));

	}

	/** Returns elementTreeViewer. */
	public TreeViewer getElementTreeViewer() {
		return elementTreeViewer;
	}

	/** Returns selectTreeViewer. */
	public TreeViewer getSelectTreeViewer() {
		return selectTreeViewer;
	}

	/** Returns selectButton. */
	public Button getSelectButton() {
		return selectButton;
	}

	/** Returns deselectButton. */
	public Button getDeselectButton() {
		return deselectButton;
	}

	/** Get the create button */
	public Button getCreateButton() {
		return createButton;
	}

	/** Get the delete button */
	public Button getDeleteButton() {
		return deleteButton;
	}

	/** Get the edit button */
	public Button getEditButton() {
		return editButton;
	}

	/** Get the tool bar */
	public Composite getLeftToolBar() {
		return lefttoolbar;
	}

}
