/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import org.fortiss.tooling.base.model.element.IHiddenSpecification;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.base.model.element.IHierarchicElementContainer;
import org.fortiss.tooling.base.model.element.IModelElementSpecification;

/**
 * Utility class for model elements.
 * 
 * @author trachtenherz
 * @author mou
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating GREEN Hash: 66CCCA68F9162A427BB1BDF853DB0146
 */
public class BaseModelElementUtils {

	/**
	 * Returns a list of specifications from {@code specifications} that are not
	 * subclass of {@link IHiddenSpecification}.
	 * 
	 * @param specifications
	 *            the list of specification to be filtered
	 */
	public static List<IModelElementSpecification> nonHiddenSpecifications(
			Collection<IModelElementSpecification> specifications) {
		List<IModelElementSpecification> res = new LinkedList<IModelElementSpecification>();
		for(IModelElementSpecification s : specifications) {
			if(!(s instanceof IHiddenSpecification)) {
				res.add(s);
			}
		}
		return res;
	}

	/**
	 * Return the index of the given {@link IHierarchicElement} in its parent
	 * {@link IHierarchicElementContainer}.
	 * 
	 * @param element
	 *            the hierarchic element
	 */
	public static int getIndex(IHierarchicElement element) {
		IHierarchicElementContainer container = element.getContainer();
		if(container != null) {
			return container.getContainedElementsList().indexOf(element);
		}
		return -1;
	}
}
