/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.utils;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

/**
 * Utility class for eclipse relevant tasks
 * 
 * @author mou
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 12F5BE532F0151DD11B20E198884443A
 */
public final class ResourceUtils {

	/**
	 * Generate the platform URI based on the given plugin ID and an absolute
	 * path.
	 * 
	 * @param pluginId
	 *            The plugin ID
	 * @param absPath
	 *            The absolute path in the plugin
	 * @return a resource URI
	 */
	public static String getResourceURI(String pluginId, String absPath) {
		if(pluginId == null) {
			throw new NullPointerException("The plugin ID must not be null!");
		}
		if(absPath == null) {
			throw new NullPointerException("The path must not be null!");
		}
		if(!absPath.startsWith("/")) {
			throw new IllegalArgumentException("The path is not a absolute path.");
		}

		return "platform:/plugin/" + pluginId + absPath;
	}

	/**
	 * Get the string content of the resource located in the given plugin at the given path.
	 * 
	 * @param pluginId
	 *            The plugin ID
	 * @param absPath
	 *            The absolute path in the plugin
	 * @return the file content
	 */
	public static List<String> getStringContentFromResource(String pluginId, String absPath)
			throws IOException {
		URL url = new URL(getResourceURI(pluginId, absPath));
		List<String> result = new ArrayList<String>();
		BufferedReader r = new BufferedReader(new InputStreamReader(url.openStream()));
		String l;
		while((l = r.readLine()) != null) {
			result.add(l);
		}
		return result;
	}
}
